[cig-commits] r14673 - in short/3D/PyLith/branches/pylith-swig: modulesrc/meshio pylith pylith/feassemble pylith/meshio unittests/pytests/meshio

brad at geodynamics.org brad at geodynamics.org
Sun Apr 12 21:31:28 PDT 2009


Author: brad
Date: 2009-04-12 21:31:26 -0700 (Sun, 12 Apr 2009)
New Revision: 14673

Added:
   short/3D/PyLith/branches/pylith-swig/pylith/meshio/CellFilterAvgMesh.py
   short/3D/PyLith/branches/pylith-swig/pylith/meshio/CellFilterAvgSubMesh.py
   short/3D/PyLith/branches/pylith-swig/pylith/meshio/DataWriterVTKMesh.py
   short/3D/PyLith/branches/pylith-swig/pylith/meshio/DataWriterVTKSubMesh.py
   short/3D/PyLith/branches/pylith-swig/pylith/meshio/DataWriterVTKSubSubMesh.py
   short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputManagerMesh.py
   short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputManagerSubMesh.py
   short/3D/PyLith/branches/pylith-swig/pylith/meshio/VertexFilterVecNormMesh.py
   short/3D/PyLith/branches/pylith-swig/pylith/meshio/VertexFilterVecNormSubMesh.py
Removed:
   short/3D/PyLith/branches/pylith-swig/pylith/meshio/CellFilterAvg.py
   short/3D/PyLith/branches/pylith-swig/pylith/meshio/VertexFilterVecNorm.py
Modified:
   short/3D/PyLith/branches/pylith-swig/modulesrc/meshio/meshio.i
   short/3D/PyLith/branches/pylith-swig/pylith/Makefile.am
   short/3D/PyLith/branches/pylith-swig/pylith/feassemble/IntegratorElasticity.py
   short/3D/PyLith/branches/pylith-swig/pylith/meshio/DataWriterVTK.py
   short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputDirichlet.py
   short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputFaultKin.py
   short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputManager.py
   short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputMatElastic.py
   short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputNeumann.py
   short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputSoln.py
   short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputSolnSubset.py
   short/3D/PyLith/branches/pylith-swig/pylith/meshio/__init__.py
   short/3D/PyLith/branches/pylith-swig/unittests/pytests/meshio/TestCellFilterAvg.py
   short/3D/PyLith/branches/pylith-swig/unittests/pytests/meshio/TestDataWriterVTK.py
   short/3D/PyLith/branches/pylith-swig/unittests/pytests/meshio/TestOutputManagerMesh.py
   short/3D/PyLith/branches/pylith-swig/unittests/pytests/meshio/TestOutputManagerSubMesh.py
   short/3D/PyLith/branches/pylith-swig/unittests/pytests/meshio/TestVertexFilterVecNorm.py
   short/3D/PyLith/branches/pylith-swig/unittests/pytests/meshio/testmeshio.py
Log:
Updated Python output objects and unit tests.

Modified: short/3D/PyLith/branches/pylith-swig/modulesrc/meshio/meshio.i
===================================================================
--- short/3D/PyLith/branches/pylith-swig/modulesrc/meshio/meshio.i	2009-04-12 22:35:35 UTC (rev 14672)
+++ short/3D/PyLith/branches/pylith-swig/modulesrc/meshio/meshio.i	2009-04-13 04:31:26 UTC (rev 14673)
@@ -78,6 +78,7 @@
 %template(SubSubMeshDataWriterVTK) pylith::meshio::DataWriterVTK<pylith::topology::SubMesh, pylith::topology::Field<pylith::topology::SubMesh> >;
 
 %template(MeshOutputManager) pylith::meshio::OutputManager<pylith::topology::Mesh, pylith::topology::Field<pylith::topology::Mesh> >;
+%template(SubMeshOutputManager) pylith::meshio::OutputManager<pylith::topology::SubMesh, pylith::topology::Field<pylith::topology::SubMesh> >;
 
 // End of file
 

Modified: short/3D/PyLith/branches/pylith-swig/pylith/Makefile.am
===================================================================
--- short/3D/PyLith/branches/pylith-swig/pylith/Makefile.am	2009-04-12 22:35:35 UTC (rev 14672)
+++ short/3D/PyLith/branches/pylith-swig/pylith/Makefile.am	2009-04-13 04:31:26 UTC (rev 14673)
@@ -57,15 +57,21 @@
 	materials/MaxwellIsotropic3D.py \
 	meshio/__init__.py \
 	meshio/CellFilter.py \
-	meshio/CellFilterAvg.py \
+	meshio/CellFilterAvgMesh.py \
+	meshio/CellFilterAvgSubMesh.py \
 	meshio/DataWriter.py \
 	meshio/DataWriterVTK.py \
+	meshio/DataWriterVTKMesh.py \
+	meshio/DataWriterVTKSubMesh.py \
+	meshio/DataWriterVTKSubSubMesh.py \
 	meshio/MeshIOObj.py \
 	meshio/MeshIOAscii.py \
 	meshio/MeshIOCubit.py \
 	meshio/MeshIOLagrit.py \
 	meshio/OutputDirichlet.py \
 	meshio/OutputManager.py \
+	meshio/OutputManagerMesh.py \
+	meshio/OutputManagerSubMesh.py \
 	meshio/OutputSoln.py \
 	meshio/OutputFaultKin.py \
 	meshio/OutputMatElastic.py \
@@ -73,7 +79,8 @@
 	meshio/OutputSolnSubset.py \
 	meshio/SingleOutput.py \
 	meshio/VertexFilter.py \
-	meshio/VertexFilterVecNorm.py \
+	meshio/VertexFilterVecNormMesh.py \
+	meshio/VertexFilterVecNormSubMesh.py \
 	mpi/__init__.py \
 	mpi/Communicator.py \
 	problems/__init__.py \

Modified: short/3D/PyLith/branches/pylith-swig/pylith/feassemble/IntegratorElasticity.py
===================================================================
--- short/3D/PyLith/branches/pylith-swig/pylith/feassemble/IntegratorElasticity.py	2009-04-12 22:35:35 UTC (rev 14672)
+++ short/3D/PyLith/branches/pylith-swig/pylith/feassemble/IntegratorElasticity.py	2009-04-13 04:31:26 UTC (rev 14673)
@@ -89,7 +89,7 @@
     Integrator.initialize(self, totalTime, numTimeSteps, normalizer)
 
     self.output.initialize(normalizer, self.materialObj.quadrature)
-    self.output.writeInfo()
+    #self.output.writeInfo()
     self.output.open(totalTime, numTimeSteps)
 
     self._logger.eventEnd(logEvent)
@@ -106,7 +106,7 @@
     Integrator.poststep(self, t, dt, totalTime, fields)
 
     self._info.log("Writing material data.")
-    self.output.writeData(t+dt, fields)
+    #self.output.writeData(t+dt, fields)
 
     self._logger.eventEnd(logEvent)
     return

Deleted: short/3D/PyLith/branches/pylith-swig/pylith/meshio/CellFilterAvg.py
===================================================================
--- short/3D/PyLith/branches/pylith-swig/pylith/meshio/CellFilterAvg.py	2009-04-12 22:35:35 UTC (rev 14672)
+++ short/3D/PyLith/branches/pylith-swig/pylith/meshio/CellFilterAvg.py	2009-04-13 04:31:26 UTC (rev 14673)
@@ -1,96 +0,0 @@
-#!/usr/bin/env python
-#
-# ----------------------------------------------------------------------
-#
-#                           Brad T. Aagaard
-#                        U.S. Geological Survey
-#
-# <LicenseText>
-#
-# ----------------------------------------------------------------------
-#
-
-## @file pyre/meshio/CellFilterAvg.py
-##
-## @brief Python class for averageing cell fields over each cell's
-## quadrature points when writing finite-element data.
-##
-## Factory: output_cell_filter
-
-from CellFilter import CellFilter
-from meshio import MeshCellFilterAvg as ModuleMeshObject
-from meshio import SubMeshCellFilterAvg as ModuleSubMeshObject
-
-# MeshCellFilterAvg class
-class MeshCellFilterAvg(CellFilter, ModuleMeshObject):
-  """
-  Python class for average cell fields over each cell's quadrature
-  points when writing finite-element data.
-
-  Factory: mesh_output_cell_filter
-  """
-
-  # PUBLIC METHODS /////////////////////////////////////////////////////
-
-  def __init__(self, name="meshcellfilteravg"):
-    """
-    Constructor.
-    """
-    CellFilter.__init__(self, name)
-    ModuleMeshObject.__init__(self)
-    return
-
-
-  def initialize(self, quadrature):
-    """
-    Initialize output manager.
-    """
-    self.quadrature(quadrature)
-    return
-
-
-# SubMeshCellFilterAvg class
-class SubMeshCellFilterAvg(CellFilter, ModuleSubMeshObject):
-  """
-  Python class for average cell fields over each cell's quadrature
-  points when writing finite-element data.
-
-  Factory: submesh_output_cell_filter
-  """
-
-  # PUBLIC METHODS /////////////////////////////////////////////////////
-
-  def __init__(self, name="submeshcellfilteravg"):
-    """
-    Constructor.
-    """
-    CellFilter.__init__(self, name)
-    ModuleSubMeshObject.__init__(self)
-    return
-
-
-  def initialize(self, quadrature):
-    """
-    Initialize output manager.
-    """
-    self.quadrature(quadrature)
-    return
-
-
-# FACTORIES ////////////////////////////////////////////////////////////
-
-def mesh_output_cell_filter():
-  """
-  Factory associated with CellFilter.
-  """
-  return MeshCellFilterAvg()
-
-
-def submesh_output_cell_filter():
-  """
-  Factory associated with CellFilter.
-  """
-  return SubMeshCellFilterAvg()
-
-
-# End of file 

Copied: short/3D/PyLith/branches/pylith-swig/pylith/meshio/CellFilterAvgMesh.py (from rev 14664, short/3D/PyLith/branches/pylith-swig/pylith/meshio/CellFilterAvg.py)
===================================================================
--- short/3D/PyLith/branches/pylith-swig/pylith/meshio/CellFilterAvgMesh.py	                        (rev 0)
+++ short/3D/PyLith/branches/pylith-swig/pylith/meshio/CellFilterAvgMesh.py	2009-04-13 04:31:26 UTC (rev 14673)
@@ -0,0 +1,60 @@
+#!/usr/bin/env python
+#
+# ----------------------------------------------------------------------
+#
+#                           Brad T. Aagaard
+#                        U.S. Geological Survey
+#
+# <LicenseText>
+#
+# ----------------------------------------------------------------------
+#
+
+## @file pyre/meshio/CellFilterAvgMesh.py
+##
+## @brief Python class for averageing cell fields over each cell's
+## quadrature points when writing finite-element data.
+##
+## Factory: output_cell_filter
+
+from CellFilter import CellFilter
+from meshio import MeshCellFilterAvg as ModuleCellFilterAvg
+
+# CellFilterAvgMesh class
+class CellFilterAvgMesh(CellFilter, ModuleCellFilterAvg):
+  """
+  Python class for average cell fields over each cell's quadrature
+  points when writing finite-element data.
+
+  Factory: output_cell_filter
+  """
+
+  # PUBLIC METHODS /////////////////////////////////////////////////////
+
+  def __init__(self, name="cellfilteravgmesh"):
+    """
+    Constructor.
+    """
+    CellFilter.__init__(self, name)
+    ModuleCellFilterAvg.__init__(self)
+    return
+
+
+  def initialize(self, quadrature):
+    """
+    Initialize output manager.
+    """
+    self.quadrature(quadrature)
+    return
+
+
+# FACTORIES ////////////////////////////////////////////////////////////
+
+def output_cell_filter():
+  """
+  Factory associated with CellFilter.
+  """
+  return CellFilterAvgMesh()
+
+
+# End of file 

Added: short/3D/PyLith/branches/pylith-swig/pylith/meshio/CellFilterAvgSubMesh.py
===================================================================
--- short/3D/PyLith/branches/pylith-swig/pylith/meshio/CellFilterAvgSubMesh.py	                        (rev 0)
+++ short/3D/PyLith/branches/pylith-swig/pylith/meshio/CellFilterAvgSubMesh.py	2009-04-13 04:31:26 UTC (rev 14673)
@@ -0,0 +1,60 @@
+#!/usr/bin/env python
+#
+# ----------------------------------------------------------------------
+#
+#                           Brad T. Aagaard
+#                        U.S. Geological Survey
+#
+# <LicenseText>
+#
+# ----------------------------------------------------------------------
+#
+
+## @file pyre/meshio/CellFilterAvgSubMesh.py
+##
+## @brief Python class for averageing cell fields over each cell's
+## quadrature points when writing finite-element data.
+##
+## Factory: output_cell_filter
+
+from CellFilter import CellFilter
+from meshio import SubMeshCellFilterAvg as ModuleCellFilterAvg
+
+# CellFilterAvgSubMesh class
+class CellFilterAvgSubMesh(CellFilter, ModuleCellFilterAvg):
+  """
+  Python class for average cell fields over each cell's quadrature
+  points when writing finite-element data.
+
+  Factory: output_cell_filter
+  """
+
+  # PUBLIC METHODS /////////////////////////////////////////////////////
+
+  def __init__(self, name="cellfilteravgsubmesh"):
+    """
+    Constructor.
+    """
+    CellFilter.__init__(self, name)
+    ModuleCellFilterAvg.__init__(self)
+    return
+
+
+  def initialize(self, quadrature):
+    """
+    Initialize output manager.
+    """
+    self.quadrature(quadrature)
+    return
+
+
+# FACTORIES ////////////////////////////////////////////////////////////
+
+def output_cell_filter():
+  """
+  Factory associated with CellFilter.
+  """
+  return CellFilterAvgSubMesh()
+
+
+# End of file 

Modified: short/3D/PyLith/branches/pylith-swig/pylith/meshio/DataWriterVTK.py
===================================================================
--- short/3D/PyLith/branches/pylith-swig/pylith/meshio/DataWriterVTK.py	2009-04-12 22:35:35 UTC (rev 14672)
+++ short/3D/PyLith/branches/pylith-swig/pylith/meshio/DataWriterVTK.py	2009-04-13 04:31:26 UTC (rev 14673)
@@ -15,8 +15,6 @@
 ## @brief Python object for writing finite-element data to VTK file.
 
 from DataWriter import DataWriter
-from meshio import MeshDataWriterVTK as ModuleMeshObject
-from meshio import SubMeshDataWriterVTK as ModuleSubMeshObject
 
 # DataWriterVTK class
 class DataWriterVTK(DataWriter):
@@ -71,89 +69,6 @@
     self.timeConstant = normalizer.nondimensionalize(self.timeConstant,
                                                      timeScale)
     return
-  
 
-# MeshDataWriterVTK class
-class MeshDataWriterVTK(DataWriterVTK, ModuleMeshObject):
-  """
-  Python object for writing finite-element data to VTK file.
 
-  Inventory
-
-  Factory: mesh_output_data_writer
-  """
-
-  # PUBLIC METHODS /////////////////////////////////////////////////////
-
-  def __init__(self, name="meshdatawritervtk"):
-    """
-    Constructor.
-    """
-    DataWriterVTK.__init__(self, name)
-    ModuleMeshObject.__init__(self)
-    return
-
-
-  def initialize(self, normalizer):
-    """
-    Initialize writer.
-    """
-    DataWriterVTK.initialize(self, normalizer)
-    
-    print "FILENAME",self.filename
-    ModuleMeshObject.filename(self, self.filename)
-    ModuleMeshObject.timeFormat(self, self.timeFormat)
-    ModuleMeshObject.timeConstant(self, self.timeConstant.value)
-    return
-  
-
-# SubMeshDataWriterVTK class
-class SubMeshDataWriterVTK(DataWriterVTK, ModuleSubMeshObject):
-  """
-  Python object for writing finite-element data to VTK file.
-
-  Inventory
-
-  Factory: submesh_output_data_writer
-  """
-
-  # PUBLIC METHODS /////////////////////////////////////////////////////
-
-  def __init__(self, name="submeshdatawritervtk"):
-    """
-    Constructor.
-    """
-    DataWriterVTK.__init__(self, name)
-    ModuleSubMeshObject.__init__(self)
-    return
-
-
-  def initialize(self, normalizer):
-    """
-    Initialize writer.
-    """
-    DataWriterVTK.initialize(self, normalizer)
-
-    ModuleSubMeshObject.filename(self, self.filename)
-    ModuleSubMeshObject.timeFormat(self, self.timeFormat)
-    ModuleSubMeshObject.timeConstant(self, self.timeConstant.value)
-    return
-  
-
-# FACTORIES ////////////////////////////////////////////////////////////
-
-def mesh_output_data_writer():
-  """
-  Factory associated with MeshDataWriterVTK.
-  """
-  return MeshDataWriterVTK()
-
-
-def submesh_output_data_writer():
-  """
-  Factory associated with SubMeshDataWriterVTK.
-  """
-  return SubMeshDataWriterVTK()
-
-
 # End of file 

Copied: short/3D/PyLith/branches/pylith-swig/pylith/meshio/DataWriterVTKMesh.py (from rev 14670, short/3D/PyLith/branches/pylith-swig/pylith/meshio/DataWriterVTK.py)
===================================================================
--- short/3D/PyLith/branches/pylith-swig/pylith/meshio/DataWriterVTKMesh.py	                        (rev 0)
+++ short/3D/PyLith/branches/pylith-swig/pylith/meshio/DataWriterVTKMesh.py	2009-04-13 04:31:26 UTC (rev 14673)
@@ -0,0 +1,62 @@
+#!/usr/bin/env python
+#
+# ----------------------------------------------------------------------
+#
+#                           Brad T. Aagaard
+#                        U.S. Geological Survey
+#
+# <LicenseText>
+#
+# ----------------------------------------------------------------------
+#
+
+## @file pyre/meshio/DataWriterVTKMesh.py
+##
+## @brief Python object for writing finite-element data to VTK file.
+
+from DataWriterVTK import DataWriterVTK
+from meshio import MeshDataWriterVTK as ModuleDataWriterVTK
+
+# DataWriterVTKMesh class
+class DataWriterVTKMesh(DataWriterVTK, ModuleDataWriterVTK):
+  """
+  Python object for writing finite-element data to VTK file.
+
+  Inventory
+
+  Factory: output_data_writer
+  """
+
+  # PUBLIC METHODS /////////////////////////////////////////////////////
+
+  def __init__(self, name="datawritervtkmesh"):
+    """
+    Constructor.
+    """
+    DataWriterVTK.__init__(self, name)
+    ModuleDataWriterVTK.__init__(self)
+    return
+
+
+  def initialize(self, normalizer):
+    """
+    Initialize writer.
+    """
+    DataWriterVTK.initialize(self, normalizer)
+    
+    ModuleDataWriterVTK.filename(self, self.filename)
+    ModuleDataWriterVTK.timeFormat(self, self.timeFormat)
+    ModuleDataWriterVTK.timeConstant(self, self.timeConstant.value)
+    return
+  
+
+# FACTORIES ////////////////////////////////////////////////////////////
+
+def output_data_writer():
+  """
+  Factory associated with DataWriter.
+  """
+  return DataWriterVTKMesh()
+
+
+# End of file 

Added: short/3D/PyLith/branches/pylith-swig/pylith/meshio/DataWriterVTKSubMesh.py
===================================================================
--- short/3D/PyLith/branches/pylith-swig/pylith/meshio/DataWriterVTKSubMesh.py	                        (rev 0)
+++ short/3D/PyLith/branches/pylith-swig/pylith/meshio/DataWriterVTKSubMesh.py	2009-04-13 04:31:26 UTC (rev 14673)
@@ -0,0 +1,62 @@
+#!/usr/bin/env python
+#
+# ----------------------------------------------------------------------
+#
+#                           Brad T. Aagaard
+#                        U.S. Geological Survey
+#
+# <LicenseText>
+#
+# ----------------------------------------------------------------------
+#
+
+## @file pyre/meshio/DataWriterVTKSubMesh.py
+##
+## @brief Python object for writing finite-element data to VTK file.
+
+from DataWriterVTK import DataWriterVTK
+from meshio import SubMeshDataWriterVTK as ModuleDataWriterVTK
+
+# DataWriterVTKSubMesh class
+class DataWriterVTKSubMesh(DataWriterVTK, ModuleDataWriterVTK):
+  """
+  Python object for writing finite-element data to VTK file.
+
+  Inventory
+
+  Factory: output_data_writer
+  """
+
+  # PUBLIC METHODS /////////////////////////////////////////////////////
+
+  def __init__(self, name="datawritervtksubmesh"):
+    """
+    Constructor.
+    """
+    DataWriterVTK.__init__(self, name)
+    ModuleDataWriterVTK.__init__(self)
+    return
+
+
+  def initialize(self, normalizer):
+    """
+    Initialize writer.
+    """
+    DataWriterVTK.initialize(self, normalizer)
+
+    ModuleDataWriterVTK.filename(self, self.filename)
+    ModuleDataWriterVTK.timeFormat(self, self.timeFormat)
+    ModuleDataWriterVTK.timeConstant(self, self.timeConstant.value)
+    return
+  
+
+# FACTORIES ////////////////////////////////////////////////////////////
+
+def output_data_writer():
+  """
+  Factory associated with DataWriter.
+  """
+  return DataWriterVTKSubMesh()
+
+
+# End of file 

Added: short/3D/PyLith/branches/pylith-swig/pylith/meshio/DataWriterVTKSubSubMesh.py
===================================================================
--- short/3D/PyLith/branches/pylith-swig/pylith/meshio/DataWriterVTKSubSubMesh.py	                        (rev 0)
+++ short/3D/PyLith/branches/pylith-swig/pylith/meshio/DataWriterVTKSubSubMesh.py	2009-04-13 04:31:26 UTC (rev 14673)
@@ -0,0 +1,62 @@
+#!/usr/bin/env python
+#
+# ----------------------------------------------------------------------
+#
+#                           Brad T. Aagaard
+#                        U.S. Geological Survey
+#
+# <LicenseText>
+#
+# ----------------------------------------------------------------------
+#
+
+## @file pyre/meshio/DataWriterVTKSubSubMesh.py
+##
+## @brief Python object for writing finite-element data to VTK file.
+
+from DataWriterVTK import DataWriterVTK
+from meshio import SubSubMeshDataWriterVTK as ModuleDataWriterVTK
+
+# DataWriterVTKSubSubMesh class
+class DataWriterVTKSubSubMesh(DataWriterVTK, ModuleDataWriterVTK):
+  """
+  Python object for writing finite-element data to VTK file.
+
+  Inventory
+
+  Factory: output_data_writer
+  """
+
+  # PUBLIC METHODS /////////////////////////////////////////////////////
+
+  def __init__(self, name="datawritervtksubmesh"):
+    """
+    Constructor.
+    """
+    DataWriterVTK.__init__(self, name)
+    ModuleDataWriterVTK.__init__(self)
+    return
+
+
+  def initialize(self, normalizer):
+    """
+    Initialize writer.
+    """
+    DataWriterVTK.initialize(self, normalizer)
+
+    ModuleDataWriterVTK.filename(self, self.filename)
+    ModuleDataWriterVTK.timeFormat(self, self.timeFormat)
+    ModuleDataWriterVTK.timeConstant(self, self.timeConstant.value)
+    return
+  
+
+# FACTORIES ////////////////////////////////////////////////////////////
+
+def output_data_writer():
+  """
+  Factory associated with DataWriter.
+  """
+  return DataWriterVTKSubSubMesh()
+
+
+# End of file 

Modified: short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputDirichlet.py
===================================================================
--- short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputDirichlet.py	2009-04-12 22:35:35 UTC (rev 14672)
+++ short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputDirichlet.py	2009-04-13 04:31:26 UTC (rev 14673)
@@ -17,10 +17,10 @@
 ##
 ## Factory: output_manager
 
-from OutputManager import SubMeshOutputManager
+from OutputManager import OutputManagerSubMesh
 
 # OutputDirichlet class
-class OutputDirichlet(SubMeshOutputManager):
+class OutputDirichlet(OutputManagerSubMesh):
   """
   Python object for managing output of finite-element information for
   Dirichlet boundary conditions.
@@ -30,7 +30,7 @@
 
   # INVENTORY //////////////////////////////////////////////////////////
 
-  class Inventory(SubMeshOutputManager.Inventory):
+  class Inventory(OutputManagerSubMesh.Inventory):
     """
     Python object for managing OutputDirichlet facilities and properties.
     """
@@ -57,7 +57,7 @@
     """
     Constructor.
     """
-    SubMeshOutputManager.__init__(self, name)
+    OutputManagerSubMesh.__init__(self, name)
     return
 
     
@@ -67,7 +67,7 @@
     """
     Set members based using inventory.
     """
-    SubMeshOutputManager._configure(self)
+    OutputManagerSubMesh._configure(self)
     self.vertexInfoFields = self.inventory.vertexInfoFields
     self.vertexDataFields = []
     self.cellInfoFields = []
@@ -77,9 +77,9 @@
 
 # FACTORIES ////////////////////////////////////////////////////////////
 
-def submesh_output_manager():
+def output_manager():
   """
-  Factory associated with OutputDirichlet.
+  Factory associated with OutputManager.
   """
   return OutputDirichlet()
 

Modified: short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputFaultKin.py
===================================================================
--- short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputFaultKin.py	2009-04-12 22:35:35 UTC (rev 14672)
+++ short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputFaultKin.py	2009-04-13 04:31:26 UTC (rev 14673)
@@ -17,10 +17,10 @@
 ##
 ## Factory: output_manager
 
-from OutputManager import SubMeshOutputManager
+from OutputManager import OutputManagerSubMesh
 
 # OutputFaultKin class
-class OutputFaultKin(SubMeshOutputManager):
+class OutputFaultKin(OutputManagerSubMesh):
   """
   Python object for managing output of finite-element information for
   faults with kinematic ruptures.
@@ -30,7 +30,7 @@
 
   # INVENTORY //////////////////////////////////////////////////////////
 
-  class Inventory(SubMeshOutputManager.Inventory):
+  class Inventory(OutputManagerSubMesh.Inventory):
     """
     Python object for managing OutputFaultKin facilities and properties.
     """
@@ -64,7 +64,7 @@
     """
     Constructor.
     """
-    SubMeshOutputManager.__init__(self, name)
+    OutputManagerSubMesh.__init__(self, name)
     return
 
     
@@ -74,7 +74,7 @@
     """
     Set members based using inventory.
     """
-    SubMeshOutputManager._configure(self)
+    OutputManagerSubMesh._configure(self)
     self.vertexInfoFields = self.inventory.vertexInfoFields
     self.vertexDataFields = self.inventory.vertexDataFields
     return
@@ -82,9 +82,9 @@
 
 # FACTORIES ////////////////////////////////////////////////////////////
 
-def submesh_output_manager():
+def output_manager():
   """
-  Factory associated with OutputFaultKin.
+  Factory associated with OutputManager.
   """
   return OutputFaultKin()
 

Modified: short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputManager.py
===================================================================
--- short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputManager.py	2009-04-12 22:35:35 UTC (rev 14672)
+++ short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputManager.py	2009-04-13 04:31:26 UTC (rev 14673)
@@ -370,243 +370,4 @@
     raise NotImplementedError("Implement _close() in derived class.")
 
 
-# MeshOutputManager class
-class MeshOutputManager(OutputManager, ModuleMeshObject):
-  """
-  Python abstract base class for managing output of finite-element
-  information.
-
-  \b Properties
-  @li None
-  
-  \b Facilities
-  @li \b writer Writer for data.
-
-  Factory: mesh_output_manager
-  """
-
-  # INVENTORY //////////////////////////////////////////////////////////
-
-  import pyre.inventory
-
-  from DataWriterVTK import MeshDataWriterVTK
-  writer = pyre.inventory.facility("writer", factory=MeshDataWriterVTK,
-                                 family="mesh_data_writer")
-  writer.meta['tip'] = "Writer for data."
-
-
-  # PUBLIC METHODS /////////////////////////////////////////////////////
-
-  def __init__(self, name="meshoutputmanager"):
-    """
-    Constructor.
-    """
-    OutputManager.__init__(self, name)
-    return
-
-
-  # PRIVATE METHODS ////////////////////////////////////////////////////
-
-  def _configure(self):
-    """
-    Set members based using inventory.
-    """
-    OutputManager._configure(self)
-    ModuleMeshObject.coordsys(self, self.inventory.coordsys)
-    ModuleMeshObject.writer(self, self.inventory.writer)
-    if None != self.vertexFilter.filter:
-      ModuleMeshObject.vertexFilter(self, self.inventory.vertexFilter)
-    if None != self.cellFilter.filter:
-      ModuleMeshObject.cellFilter(self, self.inventory.cellFilter)
-    return
-
-
-  def _createModuleObj(self):
-    """
-    Create handle to C++ object.
-    """
-    ModuleMeshObject.__init__(self)
-    return
-
-
-  def _open(self, mesh, nsteps, label, labelId):
-    """
-    Call C++ open();
-    """
-    if label != None and labelId != None:
-      ModuleMeshObject.open(self, mesh, nsteps, label, labelId)
-    else:
-      ModuleMeshObject.open(self, mesh, nsteps)
-    return
-
-
-  def _openTimeStep(self, t, mesh, label, labelId):
-    """
-    Call C++ openTimeStep();
-    """
-    if label != None and labelId != None:
-      ModuleMeshObject.openTimeStep(self, t, mesh, label, labelId)
-    else:
-      ModuleMeshObject.openTimeStep(self, t, mesh)
-    return
-
-
-  def _appendVertexField(self, t, field):
-    """
-    Call C++ appendVertexField();
-    """
-    ModuleMeshObject.appendVertexField(self, t, field)
-    return
-
-  def _appendCellField(self, t, field, label, labelId):
-    """
-    Call C++ appendCellField();
-    """
-    ModuleMeshObject.appendCellField(self, t, field)
-    return
-
-
-  def _closeTimeStep(self):
-    """
-    Call C++ closeTimeStep().
-    """
-    ModuleMeshObject.closeTimeStep(self)
-    return
-
-
-  def _close(self):
-    """
-    Call C++ close().
-    """
-    ModuleMeshObject.close(self)
-    return
-
-
-# SubMeshOutputManager class
-class SubMeshOutputManager(OutputManager, ModuleSubMeshObject):
-  """
-  Python abstract base class for managing output of finite-element
-  information.
-
-  \b Properties
-  @li None
-  
-  \b Facilities
-  @li \b writer Writer for data.
-
-  Factory: mesh_output_manager
-  """
-
-  # INVENTORY //////////////////////////////////////////////////////////
-
-  import pyre.inventory
-
-  from DataWriterVTK import SubMeshDataWriterVTK
-  writer = pyre.inventory.facility("writer", factory=SubMeshDataWriterVTK,
-                                 family="mesh_data_writer")
-  writer.meta['tip'] = "Writer for data."
-
-  # PUBLIC METHODS /////////////////////////////////////////////////////
-
-  def __init__(self, name="submeshoutputmanager"):
-    """
-    Constructor.
-    """
-    OutputManager.__init__(self, name)
-    return
-
-
-  # PRIVATE METHODS ////////////////////////////////////////////////////
-
-  def _configure(self):
-    """
-    Set members based using inventory.
-    """
-    OutputManager._configure(self)
-    ModuleSubMeshObject.coordsys(self, self.inventory.coordsys)
-    ModuleSubMeshObject.writer(self, self.inventory.writer)
-    if None != self.vertexFilter.filter:
-      ModuleSubMeshObject.vertexFilter(self, self.inventory.vertexFilter)
-    if None != self.cellFilter.filter:
-      ModuleSubMeshObject.cellFilter(self, self.inventory.cellFilter)
-    return
-
-
-  def _createModuleObj(self):
-    """
-    Create handle to C++ object.
-    """
-    ModuleSubMeshObject.__init__(self)
-    return
-
-
-  def _open(self, mesh, nsteps, label, labelId):
-    """
-    Call C++ open();
-    """
-    if label != None and labelId != None:
-      ModuleSubMeshObject.open(self, mesh, nsteps, label, labelId)
-    else:
-      ModuleSubMeshObject.open(self, mesh, nsteps)
-    return
-
-
-  def _openTimeStep(self, t, mesh, label, labelId):
-    """
-    Call C++ openTimeStep();
-    """
-    if label != None and labelId != None:
-      ModuleSubMeshObject.openTimeStep(self, t, mesh, label, labelId)
-    else:
-      ModuleSubMeshObject.openTimeStep(self, t, mesh)
-    return
-
-
-  def _appendVertexField(self, t, field):
-    """
-    Call C++ appendVertexField();
-    """
-    ModuleSubMeshObject.appendVertexField(self, t, field)
-    return
-
-  def _appendCellField(self, t, field):
-    """
-    Call C++ appendCellField();
-    """
-    ModuleSubMeshObject.appendCellField(self, t, field)
-    return
-
-
-  def _closeTimeStep(self):
-    """
-    Call C++ closeTimeStep().
-    """
-    ModuleSubMeshObject.closeTimeStep(self)
-    return
-
-
-  def _close(self):
-    """
-    Call C++ close().
-    """
-    ModuleSubMeshObject.close(self)
-    return
-
-
-# FACTORIES ////////////////////////////////////////////////////////////
-
-def mesh_output_manager():
-  """
-  Factory associated with MeshOutputManager.
-  """
-  return MeshOutputManager()
-
-
-def submesh_output_manager():
-  """
-  Factory associated with SubMeshOutputManager.
-  """
-  return SubMeshOutputManager()
-
-
 # End of file 

Added: short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputManagerMesh.py
===================================================================
--- short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputManagerMesh.py	                        (rev 0)
+++ short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputManagerMesh.py	2009-04-13 04:31:26 UTC (rev 14673)
@@ -0,0 +1,144 @@
+#!/usr/bin/env python
+#
+# ----------------------------------------------------------------------
+#
+#                           Brad T. Aagaard
+#                        U.S. Geological Survey
+#
+# <LicenseText>
+#
+# ----------------------------------------------------------------------
+#
+
+## @file pyre/meshio/OutputManagerMesh.py
+##
+## @brief Python abstract base class for managing output of
+## finite-element information.
+##
+## Factory: output_manager
+
+from OutputManager import OutputManager
+from meshio import MeshOutputManager as ModuleOutputManager
+
+# OutputManagerMesh class
+class OutputManagerMesh(OutputManager, ModuleOutputManager):
+  """
+  Python abstract base class for managing output of finite-element
+  information.
+
+  \b Properties
+  @li None
+  
+  \b Facilities
+  @li \b writer Writer for data.
+
+  Factory: output_manager
+  """
+
+  # INVENTORY //////////////////////////////////////////////////////////
+
+  import pyre.inventory
+
+  from DataWriterVTKMesh import DataWriterVTKMesh
+  writer = pyre.inventory.facility("writer", factory=DataWriterVTKMesh,
+                                   family="data_writer")
+  writer.meta['tip'] = "Writer for data."
+
+
+  # PUBLIC METHODS /////////////////////////////////////////////////////
+
+  def __init__(self, name="outputmanagermesh"):
+    """
+    Constructor.
+    """
+    OutputManager.__init__(self, name)
+    return
+
+
+  # PRIVATE METHODS ////////////////////////////////////////////////////
+
+  def _configure(self):
+    """
+    Set members based using inventory.
+    """
+    OutputManager._configure(self)
+    ModuleOutputManager.coordsys(self, self.inventory.coordsys)
+    ModuleOutputManager.writer(self, self.inventory.writer)
+    if None != self.vertexFilter.filter:
+      ModuleOutputManager.vertexFilter(self, self.inventory.vertexFilter)
+    if None != self.cellFilter.filter:
+      ModuleOutputManager.cellFilter(self, self.inventory.cellFilter)
+    return
+
+
+  def _createModuleObj(self):
+    """
+    Create handle to C++ object.
+    """
+    ModuleOutputManager.__init__(self)
+    return
+
+
+  def _open(self, mesh, nsteps, label, labelId):
+    """
+    Call C++ open();
+    """
+    if label != None and labelId != None:
+      ModuleOutputManager.open(self, mesh, nsteps, label, labelId)
+    else:
+      ModuleOutputManager.open(self, mesh, nsteps)
+    return
+
+
+  def _openTimeStep(self, t, mesh, label, labelId):
+    """
+    Call C++ openTimeStep();
+    """
+    if label != None and labelId != None:
+      ModuleOutputManager.openTimeStep(self, t, mesh, label, labelId)
+    else:
+      ModuleOutputManager.openTimeStep(self, t, mesh)
+    return
+
+
+  def _appendVertexField(self, t, field):
+    """
+    Call C++ appendVertexField();
+    """
+    ModuleOutputManager.appendVertexField(self, t, field)
+    return
+
+  def _appendCellField(self, t, field, label, labelId):
+    """
+    Call C++ appendCellField();
+    """
+    ModuleOutputManager.appendCellField(self, t, field)
+    return
+
+
+  def _closeTimeStep(self):
+    """
+    Call C++ closeTimeStep().
+    """
+    ModuleOutputManager.closeTimeStep(self)
+    return
+
+
+  def _close(self):
+    """
+    Call C++ close().
+    """
+    ModuleOutputManager.close(self)
+    return
+
+
+# FACTORIES ////////////////////////////////////////////////////////////
+
+def output_manager():
+  """
+  Factory associated with OutputManager.
+  """
+  return OutputManagerMesh()
+
+
+# End of file 

Added: short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputManagerSubMesh.py
===================================================================
--- short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputManagerSubMesh.py	                        (rev 0)
+++ short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputManagerSubMesh.py	2009-04-13 04:31:26 UTC (rev 14673)
@@ -0,0 +1,143 @@
+#!/usr/bin/env python
+#
+# ----------------------------------------------------------------------
+#
+#                           Brad T. Aagaard
+#                        U.S. Geological Survey
+#
+# <LicenseText>
+#
+# ----------------------------------------------------------------------
+#
+
+## @file pyre/meshio/OutputManagerSubMesh.py
+##
+## @brief Python abstract base class for managing output of
+## finite-element information.
+##
+## Factory: output_manager
+
+from OutputManager import OutputManager
+from meshio import SubMeshOutputManager as ModuleOutputManager
+
+# OutputManagerSubMsh class
+class OutputManagerSubMesh(OutputManager, ModuleOutputManager):
+  """
+  Python abstract base class for managing output of finite-element
+  information.
+
+  \b Properties
+  @li None
+  
+  \b Facilities
+  @li \b writer Writer for data.
+
+  Factory: output_manager
+  """
+
+  # INVENTORY //////////////////////////////////////////////////////////
+
+  import pyre.inventory
+
+  from DataWriterVTKSubSubMesh import DataWriterVTKSubSubMesh
+  writer = pyre.inventory.facility("writer", factory=DataWriterVTKSubSubMesh,
+                                   family="data_writer")
+  writer.meta['tip'] = "Writer for data."
+
+  # PUBLIC METHODS /////////////////////////////////////////////////////
+
+  def __init__(self, name="outputmanagersubmesh"):
+    """
+    Constructor.
+    """
+    OutputManager.__init__(self, name)
+    return
+
+
+  # PRIVATE METHODS ////////////////////////////////////////////////////
+
+  def _configure(self):
+    """
+    Set members based using inventory.
+    """
+    OutputManager._configure(self)
+    ModuleOutputManager.coordsys(self, self.inventory.coordsys)
+    ModuleOutputManager.writer(self, self.inventory.writer)
+    if None != self.vertexFilter.filter:
+      ModuleOutputManager.vertexFilter(self, self.inventory.vertexFilter)
+    if None != self.cellFilter.filter:
+      ModuleOutputManager.cellFilter(self, self.inventory.cellFilter)
+    return
+
+
+  def _createModuleObj(self):
+    """
+    Create handle to C++ object.
+    """
+    ModuleOutputManager.__init__(self)
+    return
+
+
+  def _open(self, mesh, nsteps, label, labelId):
+    """
+    Call C++ open();
+    """
+    if label != None and labelId != None:
+      ModuleOutputManager.open(self, mesh, nsteps, label, labelId)
+    else:
+      ModuleOutputManager.open(self, mesh, nsteps)
+    return
+
+
+  def _openTimeStep(self, t, mesh, label, labelId):
+    """
+    Call C++ openTimeStep();
+    """
+    if label != None and labelId != None:
+      ModuleOutputManager.openTimeStep(self, t, mesh, label, labelId)
+    else:
+      ModuleOutputManager.openTimeStep(self, t, mesh)
+    return
+
+
+  def _appendVertexField(self, t, field):
+    """
+    Call C++ appendVertexField();
+    """
+    ModuleOutputManager.appendVertexField(self, t, field)
+    return
+
+  def _appendCellField(self, t, field):
+    """
+    Call C++ appendCellField();
+    """
+    ModuleOutputManager.appendCellField(self, t, field)
+    return
+
+
+  def _closeTimeStep(self):
+    """
+    Call C++ closeTimeStep().
+    """
+    ModuleOutputManager.closeTimeStep(self)
+    return
+
+
+  def _close(self):
+    """
+    Call C++ close().
+    """
+    ModuleOutputManager.close(self)
+    return
+
+
+# FACTORIES ////////////////////////////////////////////////////////////
+
+def output_manager():
+  """
+  Factory associated with OutputManager.
+  """
+  return OutputManagerSubMesh()
+
+
+# End of file 

Modified: short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputMatElastic.py
===================================================================
--- short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputMatElastic.py	2009-04-12 22:35:35 UTC (rev 14672)
+++ short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputMatElastic.py	2009-04-13 04:31:26 UTC (rev 14673)
@@ -17,10 +17,10 @@
 ##
 ## Factory: output_manager
 
-from OutputManager import MeshOutputManager
+from OutputManagerMesh import OutputManagerMesh
 
 # OutputMatElastic class
-class OutputMatElastic(MeshOutputManager):
+class OutputMatElastic(OutputManagerMesh):
   """
   Python object for managing output of finite-element information for
   material state variables.
@@ -30,7 +30,7 @@
 
   # INVENTORY //////////////////////////////////////////////////////////
 
-  class Inventory(MeshOutputManager.Inventory):
+  class Inventory(OutputManagerMesh.Inventory):
     """
     Python object for managing OutputMatElastic facilities and properties.
     """
@@ -64,7 +64,7 @@
     """
     Constructor.
     """
-    MeshOutputManager.__init__(self, name)
+    OutputManagerMesh.__init__(self, name)
     return
 
     
@@ -74,7 +74,7 @@
     """
     Set members based using inventory.
     """
-    MeshOutputManager._configure(self)
+    OutputManagerMesh._configure(self)
     self.vertexInfoFields = []
     self.vertexDataFields = []
     self.cellInfoFields = self.inventory.cellInfoFields
@@ -84,9 +84,9 @@
 
 # FACTORIES ////////////////////////////////////////////////////////////
 
-def mesh_output_manager():
+def output_manager():
   """
-  Factory associated with OutputMatElastic.
+  Factory associated with OutputManager.
   """
   return OutputMatElastic()
 

Modified: short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputNeumann.py
===================================================================
--- short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputNeumann.py	2009-04-12 22:35:35 UTC (rev 14672)
+++ short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputNeumann.py	2009-04-13 04:31:26 UTC (rev 14673)
@@ -17,10 +17,10 @@
 ##
 ## Factory: output_manager
 
-from OutputManager import SubMeshOutputManager
+from OutputManagerSubMesh import OutputManagerSubMesh
 
 # OutputNeumann class
-class OutputNeumann(SubMeshOutputManager):
+class OutputNeumann(OutputManagerSubMesh):
   """
   Python object for managing output of finite-element information for
   Neumann boundary conditions.
@@ -30,7 +30,7 @@
 
   # INVENTORY //////////////////////////////////////////////////////////
 
-  class Inventory(SubMeshOutputManager.Inventory):
+  class Inventory(OutputManagerSubMesh.Inventory):
     """
     Python object for managing OutputNeumann facilities and properties.
     """
@@ -57,7 +57,7 @@
     """
     Constructor.
     """
-    SubMeshOutputManager.__init__(self, name)
+    OutputManagerSubMesh.__init__(self, name)
     return
 
     
@@ -67,7 +67,7 @@
     """
     Set members based using inventory.
     """
-    SubMeshOutputManager._configure(self)
+    OutputManagerSubMesh._configure(self)
     self.vertexInfoFields = []
     self.vertexDataFields = []
     self.cellInfoFields = self.inventory.cellInfoFields
@@ -77,9 +77,9 @@
 
 # FACTORIES ////////////////////////////////////////////////////////////
 
-def submesh_output_manager():
+def output_manager():
   """
-  Factory associated with OutputNeumann.
+  Factory associated with OutputManager.
   """
   return OutputNeumann()
 

Modified: short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputSoln.py
===================================================================
--- short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputSoln.py	2009-04-12 22:35:35 UTC (rev 14672)
+++ short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputSoln.py	2009-04-13 04:31:26 UTC (rev 14673)
@@ -17,10 +17,10 @@
 ##
 ## Factory: output_manager
 
-from OutputManager import MeshOutputManager
+from OutputManagerMesh import OutputManagerMesh
 
 # OutputSoln class
-class OutputSoln(MeshOutputManager):
+class OutputSoln(OutputManagerMesh):
   """
   Python object for managing output of finite-element solution
   information.
@@ -55,7 +55,7 @@
     """
     Constructor.
     """
-    MeshOutputManager.__init__(self, name)
+    OutputManagerMesh.__init__(self, name)
     self.availableFields = \
         {'vertex': \
            {'info': [],
@@ -70,7 +70,7 @@
     """
     Do
     """
-    MeshOutputManager.preinitialize(self, dataProvider=self)
+    OutputManagerMesh.preinitialize(self, dataProvider=self)
     return
   
 
@@ -82,7 +82,7 @@
     self._logger.eventBegin(logEvent)    
 
     self.mesh = mesh
-    MeshOutputManager.initialize(self, normalizer)
+    OutputManagerMesh.initialize(self, normalizer)
 
     self._logger.eventEnd(logEvent)
     return
@@ -113,7 +113,7 @@
     """
     Set members based using inventory.
     """
-    MeshOutputManager._configure(self)
+    OutputManagerMesh._configure(self)
     self.vertexDataFields = self.inventory.vertexDataFields
     self.cellInfoFields = self.inventory.cellInfoFields
     return
@@ -121,9 +121,9 @@
 
 # FACTORIES ////////////////////////////////////////////////////////////
 
-def mesh_output_manager():
+def output_manager():
   """
-  Factory associated with OutputSoln.
+  Factory associated with OutputManager.
   """
   return OutputSoln()
 

Modified: short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputSolnSubset.py
===================================================================
--- short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputSolnSubset.py	2009-04-12 22:35:35 UTC (rev 14672)
+++ short/3D/PyLith/branches/pylith-swig/pylith/meshio/OutputSolnSubset.py	2009-04-13 04:31:26 UTC (rev 14673)
@@ -15,7 +15,7 @@
 ## @brief Python object for managing output of finite-element solution
 ## information over a subdomain.
 ##
-## Factory: submesh_output_manager
+## Factory: output_manager
 
 from OutputManager import OutputManager
 from meshio import OutputSolnSubset as ModuleOutputSolnSubset
@@ -36,7 +36,7 @@
   \b Facilities
   @li \b writer Writer for data.
 
-  Factory: submesh_output_manager
+  Factory: output_manager
   """
 
   # INVENTORY //////////////////////////////////////////////////////////
@@ -50,9 +50,9 @@
   label = pyre.inventory.str("label", default="")
   label.meta['tip'] = "Label identifier for subdomain."
 
-  from DataWriterVTK import SubMeshDataWriterVTK
-  writer = pyre.inventory.facility("writer", factory=SubMeshDataWriterVTK,
-                                 family="mesh_data_writer")
+  from DataWriterVTKSubMesh import DataWriterVTKSubMesh
+  writer = pyre.inventory.facility("writer", factory=DataWriterVTKSubMesh,
+                                 family="data_writer")
   writer.meta['tip'] = "Writer for data."
 
 
@@ -204,9 +204,9 @@
 
 # FACTORIES ////////////////////////////////////////////////////////////
 
-def submesh_output_manager():
+def output_manager():
   """
-  Factory associated with OutputSolnSubset.
+  Factory associated with OutputManager.
   """
   return OutputSolnSubset()
 

Deleted: short/3D/PyLith/branches/pylith-swig/pylith/meshio/VertexFilterVecNorm.py
===================================================================
--- short/3D/PyLith/branches/pylith-swig/pylith/meshio/VertexFilterVecNorm.py	2009-04-12 22:35:35 UTC (rev 14672)
+++ short/3D/PyLith/branches/pylith-swig/pylith/meshio/VertexFilterVecNorm.py	2009-04-13 04:31:26 UTC (rev 14673)
@@ -1,89 +0,0 @@
-#!/usr/bin/env python
-#
-# ----------------------------------------------------------------------
-#
-#                           Brad T. Aagaard
-#                        U.S. Geological Survey
-#
-# <LicenseText>
-#
-# ----------------------------------------------------------------------
-#
-
-## @file pyre/meshio/VertexFilterVecNorm.py
-##
-## @brief Python class for computing vector norm for each vertex for
-## field over vertices when writing finite-element data.
-##
-## Factory: output_vertex_filter
-
-from VertexFilter import VertexFilter
-from meshio import MeshVertexFilterVecNorm as ModuleMeshObject
-from meshio import SubMeshVertexFilterVecNorm as ModuleSubMeshObject
-
-# MeshVertexFilterVecNorm class
-class MeshVertexFilterVecNorm(VertexFilter, ModuleMeshObject):
-  """
-  Python class for computing vector norm for each vertex for field
-  over vertices when writing finite-element data.
-
-  Factory: output_vertex_filter
-  """
-
-  # PUBLIC METHODS /////////////////////////////////////////////////////
-
-  def __init__(self, name="meshvertexfiltervecnorm"):
-    """
-    Constructor.
-    """
-    VertexFilter.__init__(self, name)
-    ModuleMeshObject.__init__(self)
-    return
-
-
-# FACTORIES ////////////////////////////////////////////////////////////
-
-def mesh_output_vertex_filter():
-  """
-  Factory associated with VertexFilter.
-  """
-  return MeshVertexFilterVecNorm()
-
-
-# SubMeshVertexFilterVecNorm class
-class SubMeshVertexFilterVecNorm(VertexFilter, ModuleSubMeshObject):
-  """
-  Python class for computing vector norm for each vertex for field
-  over vertices when writing finite-element data.
-
-  Factory: output_vertex_filter
-  """
-
-  # PUBLIC METHODS /////////////////////////////////////////////////////
-
-  def __init__(self, name="meshvertexfiltervecnorm"):
-    """
-    Constructor.
-    """
-    VertexFilter.__init__(self, name)
-    ModuleSubMeshObject.__init__(self)
-    return
-
-
-# FACTORIES ////////////////////////////////////////////////////////////
-
-def mesh_output_vertex_filter():
-  """
-  Factory associated with VertexFilter.
-  """
-  return MeshVertexFilterVecNorm()
-
-
-def submesh_output_vertex_filter():
-  """
-  Factory associated with VertexFilter.
-  """
-  return SubMeshVertexFilterVecNorm()
-
-
-# End of file 

Copied: short/3D/PyLith/branches/pylith-swig/pylith/meshio/VertexFilterVecNormMesh.py (from rev 14664, short/3D/PyLith/branches/pylith-swig/pylith/meshio/VertexFilterVecNorm.py)
===================================================================
--- short/3D/PyLith/branches/pylith-swig/pylith/meshio/VertexFilterVecNormMesh.py	                        (rev 0)
+++ short/3D/PyLith/branches/pylith-swig/pylith/meshio/VertexFilterVecNormMesh.py	2009-04-13 04:31:26 UTC (rev 14673)
@@ -0,0 +1,52 @@
+#!/usr/bin/env python
+#
+# ----------------------------------------------------------------------
+#
+#                           Brad T. Aagaard
+#                        U.S. Geological Survey
+#
+# <LicenseText>
+#
+# ----------------------------------------------------------------------
+#
+
+## @file pyre/meshio/VertexFilterVecNormMesh.py
+##
+## @brief Python class for computing vector norm for each vertex for
+## field over vertices when writing finite-element data.
+##
+## Factory: output_vertex_filter
+
+from VertexFilter import VertexFilter
+from meshio import MeshVertexFilterVecNorm as ModuleVertexFilterVecNorm
+
+# VertexFilterVecNormMesh class
+class VertexFilterVecNormMesh(VertexFilter, ModuleVertexFilterVecNorm):
+  """
+  Python class for computing vector norm for each vertex for field
+  over vertices when writing finite-element data.
+
+  Factory: output_vertex_filter
+  """
+
+  # PUBLIC METHODS /////////////////////////////////////////////////////
+
+  def __init__(self, name="vertexfiltervecnormmesh"):
+    """
+    Constructor.
+    """
+    VertexFilter.__init__(self, name)
+    ModuleVertexFilterVecNorm.__init__(self)
+    return
+
+
+# FACTORIES ////////////////////////////////////////////////////////////
+
+def output_vertex_filter():
+  """
+  Factory associated with VertexFilter.
+  """
+  return VertexFilterVecNormMesh()
+
+
+# End of file 

Added: short/3D/PyLith/branches/pylith-swig/pylith/meshio/VertexFilterVecNormSubMesh.py
===================================================================
--- short/3D/PyLith/branches/pylith-swig/pylith/meshio/VertexFilterVecNormSubMesh.py	                        (rev 0)
+++ short/3D/PyLith/branches/pylith-swig/pylith/meshio/VertexFilterVecNormSubMesh.py	2009-04-13 04:31:26 UTC (rev 14673)
@@ -0,0 +1,52 @@
+#!/usr/bin/env python
+#
+# ----------------------------------------------------------------------
+#
+#                           Brad T. Aagaard
+#                        U.S. Geological Survey
+#
+# <LicenseText>
+#
+# ----------------------------------------------------------------------
+#
+
+## @file pyre/meshio/VertexFilterVecNormSubMesh.py
+##
+## @brief Python class for computing vector norm for each vertex for
+## field over vertices when writing finite-element data.
+##
+## Factory: output_vertex_filter
+
+from VertexFilter import VertexFilter
+from meshio import SubMeshVertexFilterVecNorm as ModuleVertexFilterVecNorm
+
+# VertexFilterVecNormSubMesh class
+class VertexFilterVecNormSubMesh(VertexFilter, ModuleVertexFilterVecNorm):
+  """
+  Python class for computing vector norm for each vertex for field
+  over vertices when writing finite-element data.
+
+  Factory: output_vertex_filter
+  """
+
+  # PUBLIC METHODS /////////////////////////////////////////////////////
+
+  def __init__(self, name="vertexfiltervecnormsubmesh"):
+    """
+    Constructor.
+    """
+    VertexFilter.__init__(self, name)
+    ModuleVertexFilterVecNorm.__init__(self)
+    return
+
+
+# FACTORIES ////////////////////////////////////////////////////////////
+
+def output_vertex_filter():
+  """
+  Factory associated with VertexFilter.
+  """
+  return VertexFilterVecNormSubMesh()
+
+
+# End of file 

Modified: short/3D/PyLith/branches/pylith-swig/pylith/meshio/__init__.py
===================================================================
--- short/3D/PyLith/branches/pylith-swig/pylith/meshio/__init__.py	2009-04-12 22:35:35 UTC (rev 14672)
+++ short/3D/PyLith/branches/pylith-swig/pylith/meshio/__init__.py	2009-04-13 04:31:26 UTC (rev 14673)
@@ -15,9 +15,13 @@
 ## @brief Python PyLith meshio module initialization
 
 __all__ = ['CellFilter',
-           'CellFilterAvg',
+           'CellFilterAvgMesh',
+           'CellFilterAvgSubMesh',
            'DataWriter',
            'DataWriterVTK',
+           'DataWriterVTKMesh',
+           'DataWriterVTKSubMesh',
+           'DataWriterVTKSubSubMesh',
            'MeshIOObj',
            'MeshIOAscii',
            'MeshIOCubit',
@@ -25,13 +29,16 @@
            'OutputDirichlet',
            'OutputFaultKin',
            'OutputManager',
+           'OutputManagerMesh',
+           'OutputManagerSubMesh',
            'OutputMatElastic',
            'OutputNeumann'
            'OutputSoln',
            'OutputSolnSubset',
            'SingleOutput',
            'VertexFilter',
-           'VertexFilterVecNorm',
+           'VertexFilterVecNormMesh',
+           'VertexFilterVecNormSubMesh',
            ]
 
 

Modified: short/3D/PyLith/branches/pylith-swig/unittests/pytests/meshio/TestCellFilterAvg.py
===================================================================
--- short/3D/PyLith/branches/pylith-swig/unittests/pytests/meshio/TestCellFilterAvg.py	2009-04-12 22:35:35 UTC (rev 14672)
+++ short/3D/PyLith/branches/pylith-swig/unittests/pytests/meshio/TestCellFilterAvg.py	2009-04-13 04:31:26 UTC (rev 14673)
@@ -16,11 +16,11 @@
 
 import unittest
 
-from pylith.meshio.CellFilterAvg import MeshCellFilterAvg
-from pylith.meshio.CellFilterAvg import SubMeshCellFilterAvg
+from pylith.meshio.CellFilterAvgMesh import CellFilterAvgMesh
+from pylith.meshio.CellFilterAvgSubMesh import CellFilterAvgSubMesh
 
 # ----------------------------------------------------------------------
-class TestMeshCellFilterAvg(unittest.TestCase):
+class TestCellFilterAvgMesh(unittest.TestCase):
   """
   Unit testing of Python CellFilterAvg object.
   """
@@ -29,7 +29,7 @@
     """
     Test constructor.
     """
-    filter = MeshCellFilterAvg()
+    filter = CellFilterAvgMesh()
     filter._configure()
     return
 
@@ -54,7 +54,7 @@
     quadrature.preinitialize(spaceDim)
     quadrature.initialize()
 
-    filter = MeshCellFilterAvg()
+    filter = CellFilterAvgMesh()
     filter._configure()
     filter.initialize(quadrature)
     return
@@ -64,13 +64,13 @@
     """
     Test factory method.
     """
-    from pylith.meshio.CellFilterAvg import mesh_output_cell_filter
-    filter = mesh_output_cell_filter()
+    from pylith.meshio.CellFilterAvgMesh import output_cell_filter
+    filter = output_cell_filter()
     return
 
 
 # ----------------------------------------------------------------------
-class TestSubMeshCellFilterAvg(unittest.TestCase):
+class TestCellFilterAvgSubMesh(unittest.TestCase):
   """
   Unit testing of Python CellFilterAvg object.
   """
@@ -79,7 +79,7 @@
     """
     Test constructor.
     """
-    filter = SubMeshCellFilterAvg()
+    filter = CellFilterAvgSubMesh()
     filter._configure()
     return
 
@@ -104,7 +104,7 @@
     quadrature.preinitialize(spaceDim)
     quadrature.initialize()
 
-    filter = SubMeshCellFilterAvg()
+    filter = CellFilterAvgSubMesh()
     filter._configure()
     filter.initialize(quadrature)
     return
@@ -114,8 +114,8 @@
     """
     Test factory method.
     """
-    from pylith.meshio.CellFilterAvg import mesh_output_cell_filter
-    filter = mesh_output_cell_filter()
+    from pylith.meshio.CellFilterAvgSubMesh import output_cell_filter
+    filter = output_cell_filter()
     return
 
 

Modified: short/3D/PyLith/branches/pylith-swig/unittests/pytests/meshio/TestDataWriterVTK.py
===================================================================
--- short/3D/PyLith/branches/pylith-swig/unittests/pytests/meshio/TestDataWriterVTK.py	2009-04-12 22:35:35 UTC (rev 14672)
+++ short/3D/PyLith/branches/pylith-swig/unittests/pytests/meshio/TestDataWriterVTK.py	2009-04-13 04:31:26 UTC (rev 14673)
@@ -16,12 +16,50 @@
 
 import unittest
 
-from pylith.meshio.DataWriterVTK import MeshDataWriterVTK
-from pylith.meshio.DataWriterVTK import SubMeshDataWriterVTK
+from pylith.meshio.DataWriterVTKMesh import DataWriterVTKMesh
+from pylith.meshio.DataWriterVTKSubMesh import DataWriterVTKSubMesh
+from pylith.meshio.DataWriterVTKSubSubMesh import DataWriterVTKSubSubMesh
 
 # ----------------------------------------------------------------------
-class TestMeshDataWriterVTK(unittest.TestCase):
+class TestDataWriterVTKMesh(unittest.TestCase):
   """
+  Unit testing of Python DataWriterVTKMesh object.
+  """
+
+  def test_constructor(self):
+    """
+    Test constructor.
+    """
+    filter = DataWriterVTKMesh()
+    filter._configure()
+    return
+
+
+  def test_initialize(self):
+    """
+    Test constructor.
+    """
+    filter = DataWriterVTKMesh()
+    filter._configure()
+
+    from spatialdata.units.Nondimensional import Nondimensional
+    normalizer = Nondimensional()
+    filter.initialize(normalizer)
+    return
+
+
+  def test_factory(self):
+    """
+    Test factory method.
+    """
+    from pylith.meshio.DataWriterVTKMesh import output_data_writer
+    filter = output_data_writer()
+    return
+
+
+# ----------------------------------------------------------------------
+class TestDataWriterVTKSubMesh(unittest.TestCase):
+  """
   Unit testing of Python DataWriterVTK object.
   """
 
@@ -29,7 +67,7 @@
     """
     Test constructor.
     """
-    filter = MeshDataWriterVTK()
+    filter = DataWriterVTKSubMesh()
     filter._configure()
     return
 
@@ -38,7 +76,7 @@
     """
     Test constructor.
     """
-    filter = MeshDataWriterVTK()
+    filter = DataWriterVTKSubMesh()
     filter._configure()
 
     from spatialdata.units.Nondimensional import Nondimensional
@@ -51,13 +89,13 @@
     """
     Test factory method.
     """
-    from pylith.meshio.DataWriterVTK import mesh_output_data_writer
-    filter = mesh_output_data_writer()
+    from pylith.meshio.DataWriterVTKSubMesh import output_data_writer
+    filter = output_data_writer()
     return
 
 
 # ----------------------------------------------------------------------
-class TestSubMeshDataWriterVTK(unittest.TestCase):
+class TestDataWriterVTKSubSubMesh(unittest.TestCase):
   """
   Unit testing of Python DataWriterVTK object.
   """
@@ -66,7 +104,7 @@
     """
     Test constructor.
     """
-    filter = SubMeshDataWriterVTK()
+    filter = DataWriterVTKSubSubMesh()
     filter._configure()
     return
 
@@ -75,7 +113,7 @@
     """
     Test constructor.
     """
-    filter = SubMeshDataWriterVTK()
+    filter = DataWriterVTKSubSubMesh()
     filter._configure()
 
     from spatialdata.units.Nondimensional import Nondimensional
@@ -88,8 +126,8 @@
     """
     Test factory method.
     """
-    from pylith.meshio.DataWriterVTK import submesh_output_data_writer
-    filter = submesh_output_data_writer()
+    from pylith.meshio.DataWriterVTKSubSubMesh import output_data_writer
+    filter = output_data_writer()
     return
 
 

Modified: short/3D/PyLith/branches/pylith-swig/unittests/pytests/meshio/TestOutputManagerMesh.py
===================================================================
--- short/3D/PyLith/branches/pylith-swig/unittests/pytests/meshio/TestVertexFilterVecNorm.py	2009-04-12 22:35:35 UTC (rev 14672)
+++ short/3D/PyLith/branches/pylith-swig/unittests/pytests/meshio/TestVertexFilterVecNorm.py	2009-04-13 04:31:26 UTC (rev 14673)
@@ -16,11 +16,11 @@
 
 import unittest
 
-from pylith.meshio.VertexFilterVecNorm import MeshVertexFilterVecNorm
-from pylith.meshio.VertexFilterVecNorm import SubMeshVertexFilterVecNorm
+from pylith.meshio.VertexFilterVecNormMesh import VertexFilterVecNormMesh
+from pylith.meshio.VertexFilterVecNormSubMesh import VertexFilterVecNormSubMesh
 
 # ----------------------------------------------------------------------
-class TestMeshVertexFilterVecNorm(unittest.TestCase):
+class TestVertexFilterVecNormMesh(unittest.TestCase):
   """
   Unit testing of Python VertexFilterVecNorm object.
   """
@@ -29,7 +29,7 @@
     """
     Test constructor.
     """
-    filter = MeshVertexFilterVecNorm()
+    filter = VertexFilterVecNormMesh()
     filter._configure()
     return
 
@@ -38,7 +38,7 @@
     """
     Test constructor.
     """
-    filter = MeshVertexFilterVecNorm()
+    filter = VertexFilterVecNormMesh()
     filter._configure()
     filter.initialize()
     return
@@ -48,13 +48,13 @@
     """
     Test factory method.
     """
-    from pylith.meshio.VertexFilterVecNorm import mesh_output_vertex_filter
-    filter = mesh_output_vertex_filter()
+    from pylith.meshio.VertexFilterVecNormMesh import output_vertex_filter
+    filter = output_vertex_filter()
     return
 
 
 # ----------------------------------------------------------------------
-class TestSubMeshVertexFilterVecNorm(unittest.TestCase):
+class TestVertexFilterVecNormSubMesh(unittest.TestCase):
   """
   Unit testing of Python VertexFilterVecNorm object.
   """
@@ -63,7 +63,7 @@
     """
     Test constructor.
     """
-    filter = SubMeshVertexFilterVecNorm()
+    filter = VertexFilterVecNormSubMesh()
     filter._configure()
     return
 
@@ -72,7 +72,7 @@
     """
     Test constructor.
     """
-    filter = SubMeshVertexFilterVecNorm()
+    filter = VertexFilterVecNormSubMesh()
     filter._configure()
     filter.initialize()
     return
@@ -82,8 +82,8 @@
     """
     Test factory method.
     """
-    from pylith.meshio.VertexFilterVecNorm import submesh_output_vertex_filter
-    filter = submesh_output_vertex_filter()
+    from pylith.meshio.VertexFilterVecNormSubMesh import output_vertex_filter
+    filter = output_vertex_filter()
     return
 
 

Modified: short/3D/PyLith/branches/pylith-swig/unittests/pytests/meshio/testmeshio.py
===================================================================
--- short/3D/PyLith/branches/pylith-swig/unittests/pytests/meshio/testmeshio.py	2009-04-12 22:35:35 UTC (rev 14672)
+++ short/3D/PyLith/branches/pylith-swig/unittests/pytests/meshio/testmeshio.py	2009-04-13 04:31:26 UTC (rev 14673)
@@ -62,33 +62,42 @@
     from TestMeshIOLagrit import TestMeshIOLagrit
     suite.addTest(unittest.makeSuite(TestMeshIOLagrit))
 
-    from TestVertexFilterVecNorm import TestMeshVertexFilterVecNorm
-    suite.addTest(unittest.makeSuite(TestMeshVertexFilterVecNorm))
+    from TestVertexFilterVecNorm import TestVertexFilterVecNormMesh
+    suite.addTest(unittest.makeSuite(TestVertexFilterVecNormMesh))
 
-    from TestVertexFilterVecNorm import TestSubMeshVertexFilterVecNorm
-    suite.addTest(unittest.makeSuite(TestSubMeshVertexFilterVecNorm))
+    from TestVertexFilterVecNorm import TestVertexFilterVecNormSubMesh
+    suite.addTest(unittest.makeSuite(TestVertexFilterVecNormSubMesh))
 
-    from TestCellFilterAvg import TestMeshCellFilterAvg
-    suite.addTest(unittest.makeSuite(TestMeshCellFilterAvg))
+    from TestCellFilterAvg import TestCellFilterAvgMesh
+    suite.addTest(unittest.makeSuite(TestCellFilterAvgMesh))
 
-    from TestCellFilterAvg import TestSubMeshCellFilterAvg
-    suite.addTest(unittest.makeSuite(TestSubMeshCellFilterAvg))
+    from TestCellFilterAvg import TestCellFilterAvgSubMesh
+    suite.addTest(unittest.makeSuite(TestCellFilterAvgSubMesh))
 
-    from TestDataWriterVTK import TestMeshDataWriterVTK
-    suite.addTest(unittest.makeSuite(TestMeshDataWriterVTK))
+    from TestDataWriterVTK import TestDataWriterVTKMesh
+    suite.addTest(unittest.makeSuite(TestDataWriterVTKMesh))
 
-    from TestDataWriterVTK import TestSubMeshDataWriterVTK
-    suite.addTest(unittest.makeSuite(TestSubMeshDataWriterVTK))
+    from TestDataWriterVTK import TestDataWriterVTKSubMesh
+    suite.addTest(unittest.makeSuite(TestDataWriterVTKSubMesh))
 
-    from TestOutputManagerMesh import TestOutputManager
-    suite.addTest(unittest.makeSuite(TestOutputManager))
+    from TestDataWriterVTK import TestDataWriterVTKSubSubMesh
+    suite.addTest(unittest.makeSuite(TestDataWriterVTKSubSubMesh))
 
-    from TestOutputManagerSubMesh import TestOutputManager
-    suite.addTest(unittest.makeSuite(TestOutputManager))
+    from TestOutputManagerMesh import TestOutputManagerMesh
+    suite.addTest(unittest.makeSuite(TestOutputManagerMesh))
 
+    from TestOutputManagerSubMesh import TestOutputManagerSubMesh
+    suite.addTest(unittest.makeSuite(TestOutputManagerSubMesh))
+
     from TestOutputSolnSubset import TestOutputSolnSubset
     suite.addTest(unittest.makeSuite(TestOutputSolnSubset))
 
+    #TestOutputNeumann
+
+    #TestOutputFaultKin
+
+    #TestOutputDirichlet
+
     return suite
 
 



More information about the CIG-COMMITS mailing list
--- short/3D/PyLith/branches/pylith-swig/unittests/pytests/meshio/TestOutputManagerMesh.py	2009-04-12 22:35:35 UTC (rev 14672)
+++ short/3D/PyLith/branches/pylith-swig/unittests/pytests/meshio/TestOutputManagerMesh.py	2009-04-13 04:31:26 UTC (rev 14673)
@@ -12,11 +12,11 @@
 
 ## @file unittests/pytests/meshio/TestOutputManagerMesh.py
 
 ## @brief Unit testing of Python MeshOutputManager object.
 
 import unittest
 
-from pylith.meshio.OutputManager import MeshOutputManager
+from pylith.meshio.OutputManagerMesh import OutputManagerMesh
 
 # ----------------------------------------------------------------------
 class TestProvider(object):
@@ -113,9 +113,9 @@
 
 
 # ----------------------------------------------------------------------
-class TestOutputManager(unittest.TestCase):
+class TestOutputManagerMesh(unittest.TestCase):
   """
   Unit testing of Python MeshOutputManager object.
   """
 
   def setUp(self):
@@ -129,7 +129,7 @@
     """
     Test constructor.
     """
-    output = MeshOutputManager()
+    output = OutputManagerMesh()
     output.inventory.writer._configure()
     output._configure()
     return
@@ -140,7 +140,7 @@
     Test preinitialize().
     """
     dataProvider = TestProvider()
-    output = MeshOutputManager()
+    output = OutputManagerMesh()
     output.preinitialize(dataProvider)
     
     self.assertEqual(dataProvider, output.dataProvider)
@@ -152,7 +152,7 @@
     Test verifyConfiguration().
     """
     dataProvider = TestProvider()
-    output = MeshOutputManager()
+    output = OutputManagerMesh()
     output.preinitialize(dataProvider)
 
     output.vertexInfoFields = ["vertex info"]
@@ -168,7 +168,7 @@
     Test initialize().
     """
     # No quadrature
-    output = MeshOutputManager()
+    output = OutputManagerMesh()
     output.inventory.writer.inventory.filename = "test.vtk"
     output.inventory.writer._configure()
     output._configure()
@@ -189,7 +189,7 @@
     quadrature.inventory.cell = cell
     quadrature._configure()
     
-    output = MeshOutputManager()
+    output = OutputManagerMesh()
     output.inventory.writer.inventory.filename = "test.vtk"
     output.inventory.writer._configure()
     output._configure()
@@ -203,7 +203,7 @@
     """
     Test open() and close().
     """
-    output = MeshOutputManager()
+    output = OutputManagerMesh()
     output.inventory.writer.inventory.filename = "output.vtk"
     output.inventory.writer._configure()
     output._configure()
@@ -220,7 +220,7 @@
     """
     Test writeInfo().
     """
-    output = MeshOutputManager()
+    output = OutputManagerMesh()
     output.inventory.writer.inventory.filename = "output.vtk"
     output.inventory.writer._configure()
     output.inventory.vertexInfoFields = ["vertex info"]
@@ -241,7 +241,7 @@
     """
     Test writeData().
     """
-    output = MeshOutputManager()
+    output = OutputManagerMesh()
     output.inventory.writer.inventory.filename = "output.vtk"
     output.inventory.writer.inventory.timeFormat = "%3.1f"
     output.inventory.writer._configure()
@@ -267,7 +267,7 @@
     dataProvider = TestProvider()
 
     # Default values should be true
-    output = MeshOutputManager()
+    output = OutputManagerMesh()
     output.inventory.writer._configure()
     output._configure()
     output.preinitialize(dataProvider)
@@ -276,7 +276,7 @@
     self.assertEqual(True, output._checkWrite(3.234e+8))
 
     # Check writing based on time
-    output = MeshOutputManager()
+    output = OutputManagerMesh()
     output._configure()
     output.writer._configure()
     output.preinitialize(dataProvider)
@@ -294,7 +294,7 @@
     self.assertEqual(True, output._checkWrite(t))
     
     # Check writing based on number of steps
-    output = MeshOutputManager()
+    output = OutputManagerMesh()
     output._configure()
     output.writer._configure()
     output.preinitialize(dataProvider)
@@ -12,11 +12,11 @@
 ## @file unittests/pytests/meshio/TestOutputManagerMesh.py
 
-## @brief Unit testing of Python MeshOutputManager object.
+## @brief Unit testing of Python OutputManagerMesh object.
 
 import unittest
@@ -113,9 +113,9 @@
   """
-  Unit testing of Python MeshOutputManager object.
+  Unit testing of Python OutputManagerMesh object.
   """
 

Modified: short/3D/PyLith/branches/pylith-swig/unittests/pytests/meshio/TestOutputManagerSubMesh.py
===================================================================
--- short/3D/PyLith/branches/pylith-swig/unittests/pytests/meshio/TestOutputManagerSubMesh.py	2009-04-12 22:35:35 UTC (rev 14672)
+++ short/3D/PyLith/branches/pylith-swig/unittests/pytests/meshio/TestOutputManagerSubMesh.py	2009-04-13 04:31:26 UTC (rev 14673)
@@ -12,11 +12,11 @@
 
 ## @file unittests/pytests/meshio/TestOutputManagerSubMesh.py
 
 ## @brief Unit testing of Python SubMeshOutputManager object.
 
 import unittest
 
-from pylith.meshio.OutputManager import SubMeshOutputManager
+from pylith.meshio.OutputManagerSubMesh import OutputManagerSubMesh
 
 # ----------------------------------------------------------------------
 class TestProvider(object):
@@ -117,7 +117,7 @@
 
 
 # ----------------------------------------------------------------------
-class TestOutputManager(unittest.TestCase):
+class TestOutputManagerSubMesh(unittest.TestCase):
   """
   Unit testing of Python MeshOutputManager object.
   """
@@ -133,7 +133,7 @@
     """
     Test constructor.
     """
-    output = SubMeshOutputManager()
+    output = OutputManagerSubMesh()
     output.inventory.writer._configure()
     output._configure()
     return
@@ -144,7 +144,7 @@
     Test preinitialize().
     """
     dataProvider = TestProvider()
-    output = SubMeshOutputManager()
+    output = OutputManagerSubMesh()
     output.preinitialize(dataProvider)
     
     self.assertEqual(dataProvider, output.dataProvider)
@@ -156,7 +156,7 @@
     Test verifyConfiguration().
     """
     dataProvider = TestProvider()
-    output = SubMeshOutputManager()
+    output = OutputManagerSubMesh()
     output.preinitialize(dataProvider)
 
     output.vertexInfoFields = ["vertex info"]
@@ -172,7 +172,7 @@
     Test initialize().
     """
     # No quadrature
-    output = SubMeshOutputManager()
+    output = OutputManagerSubMesh()
     output.inventory.writer.inventory.filename = "test.vtk"
     output.inventory.writer._configure()
     output._configure()
@@ -193,7 +193,7 @@
     quadrature.inventory.cell = cell
     quadrature._configure()
     
-    output = SubMeshOutputManager()
+    output = OutputManagerSubMesh()
     output.inventory.writer.inventory.filename = "test.vtk"
     output.inventory.writer._configure()
     output._configure()
@@ -207,7 +207,7 @@
     """
     Test open() and close().
     """
-    output = SubMeshOutputManager()
+    output = OutputManagerSubMesh()
     output.inventory.writer.inventory.filename = "output.vtk"
     output.inventory.writer._configure()
     output._configure()
@@ -224,7 +224,7 @@
     """
     Test writeInfo().
     """
-    output = SubMeshOutputManager()
+    output = OutputManagerSubMesh()
     output.inventory.writer.inventory.filename = "output.vtk"
     output.inventory.writer._configure()
     output.inventory.vertexInfoFields = ["vertex info"]
@@ -245,7 +245,7 @@
     """
     Test writeData().
     """
-    output = SubMeshOutputManager()
+    output = OutputManagerSubMesh()
     output.inventory.writer.inventory.filename = "output.vtk"
     output.inventory.writer.inventory.timeFormat = "%3.1f"
     output.inventory.writer._configure()
@@ -271,7 +271,7 @@
     dataProvider = TestProvider()
 
     # Default values should be true
-    output = SubMeshOutputManager()
+    output = OutputManagerSubMesh()
     output.inventory.writer._configure()
     output._configure()
     output.preinitialize(dataProvider)
@@ -280,7 +280,7 @@
     self.assertEqual(True, output._checkWrite(3.234e+8))
 
     # Check writing based on time
-    output = SubMeshOutputManager()
+    output = OutputManagerSubMesh()
     output._configure()
     output.writer._configure()
     output.preinitialize(dataProvider)
@@ -298,7 +298,7 @@
     self.assertEqual(True, output._checkWrite(t))
     
     # Check writing based on number of steps
-    output = SubMeshOutputManager()
+    output = OutputManagerSubMesh()
     output._configure()
     output.writer._configure()
     output.preinitialize(dataProvider)
@@ -12,11 +12,11 @@
 ## @file unittests/pytests/meshio/TestOutputManagerSubMesh.py
 
-## @brief Unit testing of Python SubMeshOutputManager object.
+## @brief Unit testing of Python OutputManagerSubMesh object.
 
 import unittest

Modified: short/3D/PyLith/branches/pylith-swig/unittests/pytests/meshio/TestVertexFilterVecNorm.py
===================================================================